# Changelog

## 0.1.0-alpha.19 (2026-03-16)

Full Changelog: [v0.1.0-alpha.18...v0.1.0-alpha.19](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.18...v0.1.0-alpha.19)

### Features

* **api:** api update ([4bb1f28](https://github.com/stiggio/stigg-python/commit/4bb1f286422b3a2f0d85e2c30334f77e02828328))
* **api:** api update ([ec8a7b2](https://github.com/stiggio/stigg-python/commit/ec8a7b2058337d0f76a838b32b6df16dfc8b7556))
* **api:** api update ([88c42e9](https://github.com/stiggio/stigg-python/commit/88c42e9116863049eac3e2479a121b8149693f2a))

## 0.1.0-alpha.18 (2026-03-12)

Full Changelog: [v0.1.0-alpha.17...v0.1.0-alpha.18](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.17...v0.1.0-alpha.18)

### Features

* **api:** api update ([53eecc8](https://github.com/stiggio/stigg-python/commit/53eecc8e07d7f00afe66b1fa7fb8f75e9c2ea5e0))

## 0.1.0-alpha.17 (2026-03-10)

Full Changelog: [v0.1.0-alpha.16...v0.1.0-alpha.17](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.16...v0.1.0-alpha.17)

### Features

* **api:** added credits resources ([f1f6b4a](https://github.com/stiggio/stigg-python/commit/f1f6b4ab41f0fc667967f3910efba62144264ab7))
* **api:** api update ([ff2efcb](https://github.com/stiggio/stigg-python/commit/ff2efcbb9f3ed8c96e8a542ebd27bbf43ed1540a))
* **api:** api update ([860d584](https://github.com/stiggio/stigg-python/commit/860d584517af3b09e4495c83dff91477d63da101))
* **api:** api update ([b6518f6](https://github.com/stiggio/stigg-python/commit/b6518f697cc248164a441fc491cac130b98d8ed6))
* **api:** api update ([76f7c44](https://github.com/stiggio/stigg-python/commit/76f7c448af1ea31513f907e490f644db67bea90c))

## 0.1.0-alpha.16 (2026-03-08)

Full Changelog: [v0.1.0-alpha.15...v0.1.0-alpha.16](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.15...v0.1.0-alpha.16)

### Features

* **api:** api update ([db2bdbe](https://github.com/stiggio/stigg-python/commit/db2bdbed6edbe0ce646f7e18cbcbfd29e8aa1031))


### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([7a4dc5e](https://github.com/stiggio/stigg-python/commit/7a4dc5e43bbe85169b29be5b358544bb5677b655))

## 0.1.0-alpha.15 (2026-03-05)

Full Changelog: [v0.1.0-alpha.14...v0.1.0-alpha.15](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.14...v0.1.0-alpha.15)

### Features

* **api:** api update ([f86ddd5](https://github.com/stiggio/stigg-python/commit/f86ddd542264d150fd234645fff1af6e77a9a6e5))

## 0.1.0-alpha.14 (2026-03-05)

Full Changelog: [v0.1.0-alpha.13...v0.1.0-alpha.14](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.13...v0.1.0-alpha.14)

### Features

* **api:** api update ([21b1adb](https://github.com/stiggio/stigg-python/commit/21b1adb048342c4c358107e3e8f3951b6ce20a7b))

## 0.1.0-alpha.13 (2026-03-04)

Full Changelog: [v0.1.0-alpha.12...v0.1.0-alpha.13](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.12...v0.1.0-alpha.13)

### Features

* **api:** api update ([d642051](https://github.com/stiggio/stigg-python/commit/d6420515f0c79ccc8da924ac1343219a30039d58))


### Chores

* **internal:** codegen related update ([ab9d88f](https://github.com/stiggio/stigg-python/commit/ab9d88f63ef2d658ba91972d3159d21d91c0d802))

## 0.1.0-alpha.12 (2026-03-02)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

### Features

* **api:** api update ([0886a81](https://github.com/stiggio/stigg-python/commit/0886a81291d33417f80cd435371328f3e29fb861))

## 0.1.0-alpha.11 (2026-03-02)

Full Changelog: [v0.1.0-alpha.10...v0.1.0-alpha.11](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.10...v0.1.0-alpha.11)

### Features

* **api:** api update ([bfeabf9](https://github.com/stiggio/stigg-python/commit/bfeabf9490806ac1d1db8c77519692a25857b36a))

## 0.1.0-alpha.10 (2026-02-27)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Features

* **api:** api update ([f386b26](https://github.com/stiggio/stigg-python/commit/f386b26be09c15629c940a55b8e77f151bc067d4))
* **api:** stainless config updates ([b2b1158](https://github.com/stiggio/stigg-python/commit/b2b1158c2db7018eb525f26679ab1a6e2942135a))
* **api:** update endpoints and models ([cdd072d](https://github.com/stiggio/stigg-python/commit/cdd072decec88c323191e15f65069b7d75c43064))


### Chores

* **internal:** add request options to SSE classes ([bedf79a](https://github.com/stiggio/stigg-python/commit/bedf79a707b132a19b1867bfaf223db113df9950))
* **internal:** make `test_proxy_environment_variables` more resilient ([064c566](https://github.com/stiggio/stigg-python/commit/064c566f266c9392f1c5a68fb00b3dc71b33bf0d))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([20393b5](https://github.com/stiggio/stigg-python/commit/20393b594c1fd6d02e8d511354f29269a771f6b0))

## 0.1.0-alpha.9 (2026-02-22)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** api update ([e8824f3](https://github.com/stiggio/stigg-python/commit/e8824f3503ac74e499a192a7388c47094f4f9ae2))

## 0.1.0-alpha.8 (2026-02-20)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** api update ([09657b8](https://github.com/stiggio/stigg-python/commit/09657b8d0ea1456baa81904cb73e72ffa7abd818))
* **api:** api update ([45e9a07](https://github.com/stiggio/stigg-python/commit/45e9a07891c7ee4a30d536662ead9dbed3ea32e4))


### Bug Fixes

* **api:** correct duplicate_product parameters in products ([756ef0f](https://github.com/stiggio/stigg-python/commit/756ef0fd11a2fa278302affaa6493303809f6c68))
* **api:** rename path_id to id, remove body_id in products.duplicate_product ([364914b](https://github.com/stiggio/stigg-python/commit/364914b827a84126d7a9b6272a2904e390158856))


### Chores

* **internal:** remove mock server code ([b0699c2](https://github.com/stiggio/stigg-python/commit/b0699c25a25226134fc71204e0a8456c4716ff2c))
* update mock server docs ([15a3a47](https://github.com/stiggio/stigg-python/commit/15a3a476f02ad0279e1085d90dc4e74e79588468))

## 0.1.0-alpha.7 (2026-02-18)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** Add missing endpoints ([1d4b37d](https://github.com/stiggio/stigg-python/commit/1d4b37d85f31cb27c5a19ad3fc596aa4cda433a1))
* **api:** api update ([086f11a](https://github.com/stiggio/stigg-python/commit/086f11abb846c47c50a29355b88a15836ea23ee7))
* **api:** manual updates ([fffd1aa](https://github.com/stiggio/stigg-python/commit/fffd1aafc92a46d5ed300b3164336f51944925de))
* **api:** manual updates ([fffd1aa](https://github.com/stiggio/stigg-python/commit/fffd1aafc92a46d5ed300b3164336f51944925de))
* **api:** trigger release ([43833a2](https://github.com/stiggio/stigg-python/commit/43833a2a3f4f3aea2f9e611f56094e24ec002650))
* **api:** trigger release ([43833a2](https://github.com/stiggio/stigg-python/commit/43833a2a3f4f3aea2f9e611f56094e24ec002650))

## 0.1.0-alpha.6 (2026-02-18)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** api update ([6eee00b](https://github.com/stiggio/stigg-python/commit/6eee00ba043342ebceb6a84b8e5dd69aadbd1228))
* **api:** api update ([381c9c8](https://github.com/stiggio/stigg-python/commit/381c9c8635ba4910fdf09fe858420cb91f845575))
* **api:** api update ([ce21825](https://github.com/stiggio/stigg-python/commit/ce218252b95333ba4e410601eae49ef73874a916))
* **api:** api update ([66820e7](https://github.com/stiggio/stigg-python/commit/66820e7a140dd5ee23e32b546eab96446fd15e36))
* **api:** api update ([8dcf9a0](https://github.com/stiggio/stigg-python/commit/8dcf9a029436559d9224288f2186440a74863beb))
* **api:** api update ([bcc391d](https://github.com/stiggio/stigg-python/commit/bcc391d302738e26a2b463aa7ae7d9b1ccd6e553))
* **api:** api update ([f32546a](https://github.com/stiggio/stigg-python/commit/f32546a6307f6063119875fdc2ceefb264b661d8))
* **api:** api update ([b61d4b1](https://github.com/stiggio/stigg-python/commit/b61d4b1b23319025742d6aa84123f0a3244119ad))
* **api:** manual updates ([fcd3ece](https://github.com/stiggio/stigg-python/commit/fcd3ecea8478bcf146ba875187ec55a36353e834))
* **api:** manual updates ([e3edede](https://github.com/stiggio/stigg-python/commit/e3ededee2c4dc5f645f7b94e051309cb1764e40c))
* **api:** updated the production environment ([aa99616](https://github.com/stiggio/stigg-python/commit/aa99616261911ad05ea2cbd5a89d0f9b9314f6fe))


### Chores

* configure new SDK language ([76b0cb3](https://github.com/stiggio/stigg-python/commit/76b0cb348b917355e7133225a71c97f16ddc36c6))
* format all `api.md` files ([4350676](https://github.com/stiggio/stigg-python/commit/4350676cf5b6a33014f530c8c72208e73d9d053b))
* **internal:** bump dependencies ([da0290c](https://github.com/stiggio/stigg-python/commit/da0290c5bf5804804e02db0a785e9856d2fb9171))
* **internal:** fix lint error on Python 3.14 ([7403f4e](https://github.com/stiggio/stigg-python/commit/7403f4e8461fff3949bb6966f1fbc9f6933b370b))

## 0.1.0-alpha.5 (2026-02-08)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** api update ([7854292](https://github.com/stiggio/stigg-python/commit/7854292045c50d27de1a9741613cfc3deaacdf8c))
* **api:** api update ([19035d2](https://github.com/stiggio/stigg-python/commit/19035d2da31a5ec48d62ad0c2217daca10c9e4c4))
* **api:** api update ([0527a37](https://github.com/stiggio/stigg-python/commit/0527a378ecd371d4101c2f56095267863f04b4ec))
* **api:** manual updates ([5dca210](https://github.com/stiggio/stigg-python/commit/5dca210e56cbaf6eec4e03d6349dfd1774ab79ec))
* **api:** manual updates ([d6f73aa](https://github.com/stiggio/stigg-python/commit/d6f73aa03cb3b512383b8969dac97ad04e1929a3))
* **client:** add custom JSON encoder for extended type support ([86703a9](https://github.com/stiggio/stigg-python/commit/86703a948003ab76bd6832a61255d7161f7f26da))

## 0.1.0-alpha.4 (2026-01-29)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update stainless config ([f1ff7ec](https://github.com/stiggio/stigg-python/commit/f1ff7ecd2707ab4a1968f5cddca1a75644136413))

## 0.1.0-alpha.3 (2026-01-28)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** api update ([0f828d6](https://github.com/stiggio/stigg-python/commit/0f828d665d9f2026f560522793d6b315424e4d35))
* **api:** api update ([6ec17ad](https://github.com/stiggio/stigg-python/commit/6ec17adf0d8c4b978889755676f5d3074b8f6993))

## 0.1.0-alpha.2 (2026-01-27)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/stiggio/stigg-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([cb4996d](https://github.com/stiggio/stigg-python/commit/cb4996da81403af3f049d0c70d12ca7ce7cc3520))
* **api:** api update ([7706756](https://github.com/stiggio/stigg-python/commit/7706756ba1926cfddcdd54223197d9c49b2ea458))
* **api:** api update ([e8a240b](https://github.com/stiggio/stigg-python/commit/e8a240b5194b9a8c98ed72e3adaa5fddc814b8e4))
* **api:** comment out promotional endpoints ([60e1e7c](https://github.com/stiggio/stigg-python/commit/60e1e7c9cf3010ea1e239f51ff17c100c5c332db))
* **api:** improved cursor pagination ([cb953cc](https://github.com/stiggio/stigg-python/commit/cb953cc0a7530b5383bab867c4ad6936894901bd))

## 0.1.0-alpha.1 (2026-01-26)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/stiggio/stigg-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** added customer endpoints ([ca52e6d](https://github.com/stiggio/stigg-python/commit/ca52e6d8e130927932e8e0cacf646ca8e41078e7))
* **api:** api update ([2384ea5](https://github.com/stiggio/stigg-python/commit/2384ea56247be33f5d481335e3dd9a06f742a129))
* **api:** api update ([d262e32](https://github.com/stiggio/stigg-python/commit/d262e32f4171b373e7507e42c2f0e5d630a8ce41))
* **api:** api update ([2ff9ff9](https://github.com/stiggio/stigg-python/commit/2ff9ff922ff914369e66dfed4e90e3f7633f6a39))
* **api:** manual updates ([33e6ab1](https://github.com/stiggio/stigg-python/commit/33e6ab1119310d8ea5e0ce7018c495d0b201b072))
* **api:** manual updates ([408c84e](https://github.com/stiggio/stigg-python/commit/408c84e3a4e0857f46af8e2218f4a1737bcaa29c))
* **api:** manual updates ([e55bcad](https://github.com/stiggio/stigg-python/commit/e55bcad977fa9fa57cf6b9de0af2cce9f9da646e))
* **api:** manual updates ([7bcf910](https://github.com/stiggio/stigg-python/commit/7bcf910f7bb1750b299178f7a59839b56cfa20c7))
* **api:** update via SDK Studio ([5617c39](https://github.com/stiggio/stigg-python/commit/5617c39c42fbb57e492a3f020a284b6f7e9f7216))
* **api:** update via SDK Studio ([97e4313](https://github.com/stiggio/stigg-python/commit/97e43131abe401eeae8378787db8b33b845a4f70))
* **api:** update via SDK Studio ([b54e88a](https://github.com/stiggio/stigg-python/commit/b54e88a8e2f17d0c2945107ebdb3301e5f10a169))
* clean up environment call outs ([9569626](https://github.com/stiggio/stigg-python/commit/9569626237d0ed6a35dca344520217257abb080e))
* **client:** add support for binary request streaming ([ab062e0](https://github.com/stiggio/stigg-python/commit/ab062e027351c58c3ac30aa6e681de14208d59e9))
* **client:** support file upload requests ([1f6e2ed](https://github.com/stiggio/stigg-python/commit/1f6e2ed3579a2e5e36871ab121a6b7125558216a))


### Bug Fixes

* **client:** don't send Content-Type header on GET requests ([9e80b71](https://github.com/stiggio/stigg-python/commit/9e80b711f0db270a0cabddc37642f2863e66ea9b))
* compat with Python 3.14 ([20c4f4c](https://github.com/stiggio/stigg-python/commit/20c4f4c7bb67ab2664f1ea96d5081a998a312732))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([6483a54](https://github.com/stiggio/stigg-python/commit/6483a54b976b4838881e4e461762c9170590f073))
* ensure streams are always closed ([cd64484](https://github.com/stiggio/stigg-python/commit/cd6448493343bbc95ae9802de7a998ebd2fa6921))
* **parsing:** correctly handle nested discriminated unions ([17587f2](https://github.com/stiggio/stigg-python/commit/17587f2501f8769956012fe7d5b3c36b08dc21dc))
* **parsing:** ignore empty metadata ([cce02c3](https://github.com/stiggio/stigg-python/commit/cce02c3acfcf557d7a5406d9218cbd6f15e39102))
* **parsing:** parse extra field types ([aa74584](https://github.com/stiggio/stigg-python/commit/aa7458479e955d35ecff1374a3cdb3fe538cba2a))
* use async_to_httpx_files in patch method ([a965ff1](https://github.com/stiggio/stigg-python/commit/a965ff1d0bcbc731fcf16f49e61f0273985d20a7))


### Chores

* add Python 3.14 classifier and testing ([08d8682](https://github.com/stiggio/stigg-python/commit/08d868213fa00ab27258a40f49ef66f47bd3b9d0))
* **ci:** upgrade `actions/github-script` ([7902494](https://github.com/stiggio/stigg-python/commit/79024947fa7a3febbb847f70bbaf771c7148f128))
* configure new SDK language ([e27d809](https://github.com/stiggio/stigg-python/commit/e27d80998d6471c0750cfe431f34bb88764493c2))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([b0da9be](https://github.com/stiggio/stigg-python/commit/b0da9befe88822c362aecc56be48c995a0493eca))
* **internal/tests:** avoid race condition with implicit client cleanup ([bcd2194](https://github.com/stiggio/stigg-python/commit/bcd2194d1746812841fad2184183dfdac09c55f8))
* **internal:** add `--fix` argument to lint script ([22d02dd](https://github.com/stiggio/stigg-python/commit/22d02dd493c319f882854d329d0f0c0fcd9da50e))
* **internal:** add missing files argument to base client ([fd30d29](https://github.com/stiggio/stigg-python/commit/fd30d2922734c52ccccc92bd97a76b7428a050f2))
* **internal:** bump pinned h11 dep ([68bbfb1](https://github.com/stiggio/stigg-python/commit/68bbfb177bebf495de82ba116bb2983a4d52644c))
* **internal:** codegen related update ([661eafb](https://github.com/stiggio/stigg-python/commit/661eafbf676a9ab947d59d94430643c74bebb4d4))
* **internal:** codegen related update ([0b6a4c2](https://github.com/stiggio/stigg-python/commit/0b6a4c2f9bb08639653069a2a6370d4eba1bc48f))
* **internal:** fix ruff target version ([5c10751](https://github.com/stiggio/stigg-python/commit/5c10751f1815d41f9910e8b19d83bd64ee24a893))
* **internal:** grammar fix (it's -&gt; its) ([7d3a5b4](https://github.com/stiggio/stigg-python/commit/7d3a5b4a66cbfb97fd50a11f4c9edb12b81fcce0))
* **internal:** update `actions/checkout` version ([160fe5d](https://github.com/stiggio/stigg-python/commit/160fe5d9898e553afb0663e0947206b580570038))
* **internal:** update comment in script ([cb98268](https://github.com/stiggio/stigg-python/commit/cb982683eef08d89a74f3662ec64ebee7e967545))
* **package:** drop Python 3.8 support ([0ff6c51](https://github.com/stiggio/stigg-python/commit/0ff6c513884b26f7ce53f9c99a6e80aaee0efd9f))
* **package:** mark python 3.13 as supported ([072b841](https://github.com/stiggio/stigg-python/commit/072b8414da27724eca52a57ce1eb35a0b13f1b48))
* **project:** add settings file for vscode ([a4c8f17](https://github.com/stiggio/stigg-python/commit/a4c8f17dc31a4253e0e10379a71cbc07f288d50d))
* **readme:** fix version rendering on pypi ([8a8a08c](https://github.com/stiggio/stigg-python/commit/8a8a08c2c59e8fcb5d2948b591732a5196ff2c13))
* speedup initial import ([c047340](https://github.com/stiggio/stigg-python/commit/c047340c56c0303a0cb1fbc30fafaf6b2df1a000))
* update @stainless-api/prism-cli to v5.15.0 ([677f30d](https://github.com/stiggio/stigg-python/commit/677f30dfdd61668703ad529b7c7f8d8cd87b9eef))
* update SDK settings ([3d37414](https://github.com/stiggio/stigg-python/commit/3d374148654dec3c7bc0a49b21f9081a90c6a1dc))
* update SDK settings ([a71fc34](https://github.com/stiggio/stigg-python/commit/a71fc34532b125523aabcaa85b996005ac6bfe81))
